package Lingua::Enlist;

use strict;
use vars qw($VERSION @ISA @EXPORT $AUTOLOAD);

require Exporter;

@ISA = qw(Exporter);
@EXPORT = qw( enlist);
$VERSION = '0.01';

my %language =
(
	English   => { sep => ',', alt => ";", con => 'and' },
	Francais  => { sep => ',', alt => ";", con => 'et'  },
	Italiano  => { sep => ',', alt => ";", con => 'e'   },
	Deutche   => { sep => ',', alt => ";", con => 'und' },
	Espanol   => { sep => ',', alt => ";", con => 'y'   },
	Klingon   => { sep => ',', alt => ";", con => 'je'  },
);

my %punct = %{$language{English}};

sub separator    { $punct{sep} = $_[1] }
sub altseparator { $punct{alt} = $_[1] }
sub connector    { $punct{con} = $_[1] }

sub AUTOLOAD {
	$AUTOLOAD =~ s/.*:://;
	my $data = $language{$AUTOLOAD} or die "No data for $AUTOLOAD";
	%punct = %{$language{$AUTOLOAD}};
}

sub enlist {
	return $_[0] if @_ < 2;
	return join " $punct{con} ", @_ if @_ == 2;
	return join "$punct{sep} ", @_[0..$#_-1], "$punct{con} $_[-1]"
		unless grep /$punct{sep}/, @_;
	return join "$punct{alt} ", @_[0..$#_-1], "$punct{con} $_[-1]";
}

1;
__END__

=head1 NAME

Lingua::Enlist - Convert Perl lists into linguistic lists

=head1 SYNOPSIS

  use Lingua::Enlist;

  # emits "Jack"
  $name_list = enlist('Jack');

  # emits "Jack and Jill"
  $name_list = enlist('Jack', 'Jill');
  
  # emits "Jack, Jill, and Spot"
  $name_list = enlist('Jack', 'Jill', 'Spot');

  # emits "Jack, a boy; Jill, a girl; and Spot, a dog"
  $name_list = enlist('Jack, a boy', 'Jill, a girl', 'Spot, a dog');

  # emits "Jacques, un garcon; Jeanne, une fille; et Spot, un chien"
  Lingua::Enlist->Francais;
  $name_list = enlist('Jacques, un garcon', 'Jeanne, une fille', 'Spot, un chien');


=head1 DESCRIPTION

Lingua::Enlist exports a single subroutine, C<enlist>, that converts a
list into a properly punctuated text string.

You can cause C<enlist> to use the connectives of other languages, by
calling the appropriate subroutine:

	Lingua::Enlist->English;	# use "and"
	Lingua::Enlist->Francais;	# use "et"
	Lingua::Enlist->Italiano;	# use "e"
	Lingua::Enlist->Espanol;	# use "y"
	Lingua::Enlist->Deutche;	# use "und"
	Lingua::Enlist->Klingon;	# Today is a good day to use "je"!

You can also set connectives individually:

	Lingua::Enlist->separator("...");
	Lingua::Enlist->altseparator("--");
	Lingua::Enlist->connector("or");

        # emits "Jack... Jill... or Spot"
        $name_list = enlist('Jack', 'Jill', 'Spot');

The "altseparator" is used whenever the separator already appears in
an item of the list. For example:

  	# emits "Doe, a deer; Ray; and Me"
  	$name_list = enlist('Doe, a deer', 'Ray', 'Me');


=head1 AUTHORS

Robert Rothenberg <wlkngowl@unix.asb.com>

Damian Conway <damian@csse.monash.edu.au>

=cut
